@@ -31,7 +31,10 @@ var DemoLibrary = {
 
       }).then(response => response.text())
         .then((response) => {
-          NativeModules.ToastExample.show('Awesome', NativeModules.ToastExample.SHORT);
+          //NativeModules.ToastExample.show('Awesome', NativeModules.ToastExample.SHORT);
+          NativeModules.DemoModuleExample.getPackageName((value)=>{
+            console.log('package ', value);
+          });
           const $ = cheerio.load(response)
           var version = $('<div/>').html(response).contents().find('div[itemprop=\"softwareVersion\"]').text().trim()
           console.log('version ', version)
