@@ -27,9 +27,5 @@ public class AnExampleReactPackage implements ReactPackage {
     return modules;
   }
 
-  @Override
-  public List<Class<? extends JavaScriptModule>> createJSModules() {
-    return null;
-  }
 
 }
\ No newline at end of file
