@@ -20,7 +20,8 @@ public class DemoModule extends ReactContextBaseJavaModule {
     }
 
     @ReactMethod
-    public String getPackageName() {
-        return getReactApplicationContext().getPackageName();
+    public void getPackageName(Callback successCallback) {
+successCallback.invoke(getReactApplicationContext().getPackageName());
+        
     }
 }
